# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class PasswordWithShow(Component):
    """A PasswordWithShow component.
Password input with a show/hide icon that can be clicked
to reveal the password

Keyword arguments:
- tooltip (string; optional): tooltip to associate with glyph
- id (string; optional): The ID of this component, used to identify dash components
in callbacks. The ID needs to be unique across all of the
components in an app.
- style (dict; optional): Defines CSS styles which will override styles previously set.
- className (string; optional): Often used with CSS to style elements with common properties.
- key (string; optional): A unique identifier for the component, used to improve
performance by React.js while rendering components
See https://reactjs.org/docs/lists-and-keys.html for more info
- value (string | number; optional): The value of the Input
- disabled (boolean; optional): Set to True to disable the Input.
- autoComplete (string; optional): This attribute indicates whether the value of the control can be
automatically completed by the browser.
- autoFocus (string; optional): The element should be automatically focused after the page has loaded.
- inputMode (a value equal to: "verbatim", "latin", "latin-name", "latin-prose", "full-width-latin", "kana", "katakana", "numeric", "tel", "email", "url"; optional): The inputmode global attribute is an enumerated attribute that provides 
a hint as to the type of data that might be entered by the user while 
editing the element or its contents. It can have the following values
- list (string; optional): Identifies a list of pre-defined options to suggest to the user.
The value must be the id of a <datalist> element in the same document.
The browser displays only options that are valid values for this
input element.
This attribute is ignored when the type attribute's value is
hidden, checkbox, radio, file, or a button type.
- max (string | number; optional): The maximum (numeric or date-time) value for this item, which must not be
less than its minimum (min attribute) value.
- maxLength (string; optional): If the value of the type attribute is text, email, search, password, tel,
or url, this attribute specifies the maximum number of characters
(in UTF-16 code units) that the user can enter. For other control types,
it is ignored. It can exceed the value of the size attribute. If it is not
specified, the user can enter an unlimited number of characters.
Specifying a negative number results in the default behavior (i.e. the
user can enter an unlimited number of characters). The constraint is
evaluated only when the value of the attribute has been changed.
- min (string | number; optional): The minimum (numeric or date-time) value for this item, which must not be
greater than its maximum (max attribute) value.
- minLength (string; optional): If the value of the type attribute is text, email, search, password, tel,
or url, this attribute specifies the minimum number of characters (in
Unicode code points) that the user can enter. For other control types, it
is ignored.
- step (string | number; optional): Works with the min and max attributes to limit the increments at which a
numeric or date-time value can be set. It can be the string any or a
positive floating point number. If this attribute is not set to any, the
control accepts only values at multiples of the step value greater than
the minimum.
- size (string; optional): The initial size of the control. This value is in pixels unless the value
of the type attribute is text or password, in which case it is an integer
number of characters. This attribute applies only when the type attribute
is set to text, search, tel, url, email, or password, otherwise it is
ignored. In addition, the size must be greater than zero. If you do not
specify a size, a default value of 20 is used.
- bs_size (string; optional): Set the size of the Input. Options: 'sm' (small), 'md' (medium)
or 'lg' (large). Default is 'md'.
- valid (boolean; optional): Apply valid style to the Input for feedback purposes. This will cause
any FormFeedback in the enclosing FormGroup with valid=True to display.
- invalid (boolean; optional): Apply invalid style to the Input for feedback purposes. This will cause
any FormFeedback in the enclosing FormGroup with valid=False to display.
- plaintext (boolean; optional): Set to true for a readonly input styled as plain text with the default
form field styling removed and the correct margins and padding preserved.
- placeholder (string; optional): A hint to the user of what can be entered in the control . The placeholder
text must not contain carriage returns or line-feeds. Note: Do not use the
placeholder attribute instead of a <label> element, their purposes are
different. The <label> attribute describes the role of the form element
(i.e. it indicates what kind of information is expected), and the
placeholder attribute is a hint about the format that the content should
take. There are cases in which the placeholder attribute is never
displayed to the user, so the form must be understandable without it.
- name (string; optional): The name of the control, which is submitted with the form data.
- pattern (string; optional): A regular expression that the control's value is checked against. The
pattern must match the entire value, not just some subset. Use the title
attribute to describe the pattern to help the user. This attribute applies
when the value of the type attribute is text, search, tel, url, email, or
password, otherwise it is ignored. The regular expression language is the
same as JavaScript RegExp algorithm, with the 'u' parameter that makes it
treat the pattern as a sequence of unicode code points. The pattern is not
surrounded by forward slashes.
- n_submit (number; default 0): Number of times the `Enter` key was pressed while the input had focus.
- n_submit_timestamp (number; default -1): Last time that `Enter` was pressed.
- n_blur (number; default 0): Number of times the input lost focus.
- n_blur_timestamp (number; default -1): Last time the input lost focus.
- debounce (boolean; default False): If true, changes to input will be sent back to the Dash server
only when the enter key is pressed or when the component loses
focus.  If it's false, it will sent the value back on every
change.
- loading_state (dict; optional): Object that holds the loading state object coming from dash-renderer. loading_state has the following type: dict containing keys 'is_loading', 'prop_name', 'component_name'.
Those keys have the following types:
  - is_loading (boolean; optional): Determines if the component is loading or not
  - prop_name (string; optional): Holds which property is loading
  - component_name (string; optional): Holds the name of the component that is loading"""
    @_explicitize_args
    def __init__(self, tooltip=Component.UNDEFINED, id=Component.UNDEFINED, style=Component.UNDEFINED, className=Component.UNDEFINED, key=Component.UNDEFINED, value=Component.UNDEFINED, disabled=Component.UNDEFINED, autoComplete=Component.UNDEFINED, autoFocus=Component.UNDEFINED, inputMode=Component.UNDEFINED, list=Component.UNDEFINED, max=Component.UNDEFINED, maxLength=Component.UNDEFINED, min=Component.UNDEFINED, minLength=Component.UNDEFINED, step=Component.UNDEFINED, size=Component.UNDEFINED, bs_size=Component.UNDEFINED, valid=Component.UNDEFINED, invalid=Component.UNDEFINED, plaintext=Component.UNDEFINED, placeholder=Component.UNDEFINED, name=Component.UNDEFINED, pattern=Component.UNDEFINED, n_submit=Component.UNDEFINED, n_submit_timestamp=Component.UNDEFINED, n_blur=Component.UNDEFINED, n_blur_timestamp=Component.UNDEFINED, debounce=Component.UNDEFINED, loading_state=Component.UNDEFINED, **kwargs):
        self._prop_names = ['tooltip', 'id', 'style', 'className', 'key', 'value', 'disabled', 'autoComplete', 'autoFocus', 'inputMode', 'list', 'max', 'maxLength', 'min', 'minLength', 'step', 'size', 'bs_size', 'valid', 'invalid', 'plaintext', 'placeholder', 'name', 'pattern', 'n_submit', 'n_submit_timestamp', 'n_blur', 'n_blur_timestamp', 'debounce', 'loading_state']
        self._type = 'PasswordWithShow'
        self._namespace = 'dash_holoniq_components/_components'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['tooltip', 'id', 'style', 'className', 'key', 'value', 'disabled', 'autoComplete', 'autoFocus', 'inputMode', 'list', 'max', 'maxLength', 'min', 'minLength', 'step', 'size', 'bs_size', 'valid', 'invalid', 'plaintext', 'placeholder', 'name', 'pattern', 'n_submit', 'n_submit_timestamp', 'n_blur', 'n_blur_timestamp', 'debounce', 'loading_state']
        self.available_wildcard_properties =            []

        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(PasswordWithShow, self).__init__(**args)
